@@ -1,3 +1,4 @@
+import logging
 from typing import Union
 
 from tlstrust import TrustStore, context
@@ -6,6 +7,8 @@ from ...transport import TLSTransport
 from ...certificate import BaseCertificate, RootCertificate
 from .. import BaseEvaluationTask
 
+logger = logging.getLogger(__name__)
+
 
 class EvaluationTask(BaseEvaluationTask):
     def __init__(  # pylint: disable=useless-super-delegation
@@ -17,6 +20,9 @@ class EvaluationTask(BaseEvaluationTask):
         if not isinstance(certificate, RootCertificate):
             raise EvaluationNotRelevant
         if not certificate.subject_key_identifier:
+            reason = f"Missing SKI RootCertificate {certificate.issuer_common_name}"
+            logger.warning(reason)
+            self.substitution_metadata["reason"] = reason
             raise NoLogEvaluation
 
         return TrustStore(certificate.subject_key_identifier).check_trust(
